@@ -131,7 +131,7 @@ class ArchivingApplication:
                 self.__componentUi.showVerbose("Backup creation for one or more archives finished with error(s)! " +
                                                "Check program's output for details.")
 
-        return self.__actionResult == self.__ActionResults.Successful
+        return self.__computeReturnValue()
 
     # }}} create action
 
@@ -203,7 +203,7 @@ class ArchivingApplication:
 
         self.__componentUi.messageShown -= self.__onMessageShown
 
-        return self.__actionResult == self.__ActionResults.Successful
+        return self.__computeReturnValue()
 
 
 
@@ -388,6 +388,11 @@ class ArchivingApplication:
 
 
 
+    def __computeReturnValue(self):
+        return self.__actionResult == self.__ActionResults.Successful
+
+
+
     def __getOrphanedArchives(self, selectedArchiveSpecs):
         knownValidArchiveNames = frozenset(self.__getKnownValidArchiveNames(selectedArchiveSpecs))
         return (name
