@@ -3,7 +3,7 @@
 # Project: AutoArchive
 # License: GNU GPLv3
 #
-# Copyright (C) 2003 - 2021 Róbert Čerňanský
+# Copyright (C) 2003 - 2022 Róbert Čerňanský
 
 
 
@@ -63,13 +63,12 @@ class Starter(metaclass = ABCMeta):
 
 
     @classmethod
-    def start(cls):
+    def start(cls, args = sys.argv):
         "Initializes and starts the program."
 
-        result = 1
         try:
-            optparseValues, arguments = cls.__parseArguments()
-            appEnvironment = AppEnvironment(os.path.basename(sys.argv[0]), optparseValues, arguments)
+            optparseValues, arguments = cls.__parseArguments(args[1:])
+            appEnvironment = AppEnvironment(os.path.basename(args[0]), optparseValues, arguments)
             configuration = ConfigurationFactory.makeConfiguration(appEnvironment)
             storage = FileStorage(configuration)
 
@@ -81,19 +80,17 @@ class Starter(metaclass = ABCMeta):
 
             archivingApplication = ArchivingApplication(cmdlineUi, applicationContext, serviceAccessor)
 
-            result = UserActionExecutor(cmdlineUi, applicationContext, archivingApplication).execute()
+            return 0 if UserActionExecutor(cmdlineUi, applicationContext, archivingApplication).execute() else 1
         except KeyboardInterrupt:
             print("\nAborted by user.")
-            result = 1
+            return 1
         except Exception as ex:
             import traceback
             if Constants.DEBUG:
                 print(traceback.print_exc())
             else:
                 Utils.printError(str.format("Exception occurred: {}.", traceback.format_exception_only(type(ex), ex)))
-            result = 1
-        finally:
-            return result
+            return 1
 
 
 
@@ -107,7 +104,7 @@ class Starter(metaclass = ABCMeta):
 
 
     @classmethod
-    def __parseArguments(cls):
+    def __parseArguments(cls, args):
         "Parses command line arguments."
 
         # define usage and version strings
@@ -420,7 +417,7 @@ specifications directory (see option --{}).""", Options.ARCHIVE_SPECS_DIR)
 
         # }}} negation options
 
-        return parser.parse_args()
+        return parser.parse_args(args)
 
 
 
